@@ -165,11 +165,6 @@ ERROR_TESTS = {
     'gamelift': {'DescribeBuild': {'BuildId': 'fake-build-id'}},
     'glacier': {'ListVaults': {'accountId': 'fake'}},
     'iam': {'GetUser': {'UserName': 'fake'}},
-    'importexport': {'CreateJob': {
-        'JobType': 'Import',
-        'ValidateOnly': False,
-        'Manifest': 'fake',
-        }},
     'kinesis': {'DescribeStream': {'StreamName': 'fake'}},
     'kms': {'GetKeyPolicy': {'KeyId': 'fake', 'PolicyName': 'fake'}},
     'lambda': {'Invoke': {'FunctionName': 'fake'}},
@@ -198,7 +193,7 @@ ERROR_TESTS = {
         }},
     'swf': {'DescribeDomain': {'name': 'fake'}},
     'waf': {'GetWebACL': {'WebACLId': 'fake'}},
-    'workspaces': {'DescribeWorkspaces': {'DirectoryId': 'fake'}},
+    'workspaces': {'DescribeWorkspaces': {'DirectoryId': 'fake-directory-id'}},
 }
 
 REGION = 'us-east-1'
